@@ -65,12 +65,13 @@ Implementation
     :align: center
 """
 
-__all__ = "MDSmartTile"
+__all__ = [
+    "MDSmartTile",
+]
 
 import os
 
 from kivy.lang import Builder
-from kivy.logger import Logger
 from kivy.properties import (
     BooleanProperty,
     ColorProperty,
